# Technical Support

*Getting Help with the Swarms Multi-Agent Framework*

---

## **Getting Started with Support**

The Swarms team is committed to providing exceptional technical support to help you build production-grade multi-agent systems. Whether you're experiencing bugs, need implementation guidance, or want to request new features, we have multiple channels to ensure you get the help you need quickly and efficiently.

---

## **Support Channels Overview**

| **Support Type** | **Best For** | **Response Time** | **Channel** |
|------------------|--------------|-------------------|-------------|
| **Bug Reports** | Code issues, errors, unexpected behavior | < 24 hours | [GitHub Issues](https://github.com/kyegomez/swarms/issues) |
| **Feature Requests** | New capabilities, enhancements | < 48 hours | [Email kye@swarms.world](mailto:kye@swarms.world) |
| **Private Issues** | Security concerns, enterprise consulting | < 4 hours | [Book Support Call](https://cal.com/swarms/swarms-technical-support?overlayCalendar=true) |
| **Real-time Help** | Quick questions, community discussions | Immediate | [Discord Community](https://discord.gg/jM3Z6M9uMq) |
| **Documentation** | Usage guides, examples, tutorials | Self-service | [docs.swarms.world](https://docs.swarms.world) |

---

## **Reporting Bugs & Technical Issues**

### **When to Use GitHub Issues**

Use GitHub Issues for:

- Code bugs and errors

- Installation problems

- Documentation issues

- Performance problems

- API inconsistencies

- Public technical discussions

### **How to Create an Effective Bug Report**

1. **Visit our Issues page**: [https://github.com/kyegomez/swarms/issues](https://github.com/kyegomez/swarms/issues)

2. **Search existing issues** to avoid duplicates

3. **Click "New Issue"** and select the appropriate template

4. **Include the following information**:

## Bug Description

A clear description of what the bug is.

## Environment

- Swarms version: [e.g., 5.9.2]

- Python version: [e.g., 3.9.0]

- Operating System: [e.g., Ubuntu 20.04, macOS 14, Windows 11]

- Model provider: [e.g., OpenAI, Anthropic, Groq]


## Steps to Reproduce

1. Step one
2. Step two
3. Step three

## Expected Behavior

What you expected to happen.

## Actual Behavior

What actually happened.

## Code Sample

```python
# Minimal code that reproduces the issue
from swarms import Agent

agent = Agent(model_name="gpt-4o-mini")
result = agent.run("Your task here")
```

## Error Messages

Paste any error messages or stack traces here


## Additional Context

Any other context, screenshots, or logs that might help.

### **Issue Templates Available**

| Template | Use Case |
|----------|----------|
| **Bug Report** | Standard bug reporting template |
| **Documentation** | Issues with docs, guides, examples |
| **Feature Request** | Suggesting new functionality |
| **Question** | General questions about usage |
| **Enterprise** | Enterprise-specific issues |

---

## **Private & Enterprise Support**

### **When to Book a Private Support Call**

Book a private consultation for:

- Security vulnerabilities or concerns

- Enterprise deployment guidance

- Custom implementation consulting

- Architecture review sessions

- Performance optimization

- Integration troubleshooting

- Strategic technical planning


### **How to Schedule Support**

1. **Visit our booking page**: [https://cal.com/swarms/swarms-technical-support?overlayCalendar=true](https://cal.com/swarms/swarms-technical-support?overlayCalendar=true)

2. **Select an available time** that works for your timezone

3. **Provide details** about your issue or requirements

4. **Prepare for the call**:
   - Have your code/environment ready

   - Prepare specific questions

   - Include relevant error messages or logs

   - Share your use case and goals


### **What to Expect**

- **Direct access** to Swarms core team members

- **Screen sharing** for live debugging

- **Custom solutions** tailored to your needs

- **Follow-up resources** and documentation

- **Priority support** for implementation


---

## **Real-Time Community Support**

### **Join Our Discord Community**

Get instant help from our active community of developers and core team members.

**Discord Benefits:**

- **24/7 availability** - Someone is always online

- **Instant responses** - Get help in real-time

- **Community wisdom** - Learn from other developers

- **Specialized channels** - Find the right help quickly

- **Latest updates** - Stay informed about new releases


### **Discord Channels Guide**

| Channel | Purpose |
|---------|---------|
| **#general** | General discussions and introductions |
| **#technical-support** | Technical questions and troubleshooting |
| **#showcase** | Share your Swarms projects and demos |
| **#feature-requests** | Discuss potential new features |
| **#announcements** | Official updates and releases |
| **#resources** | Helpful links, tutorials, and guides |

### **Getting Help on Discord**

1. **Join here**: [https://discord.gg/jM3Z6M9uMq](https://discord.gg/jM3Z6M9uMq)

2. **Read the rules** and introduce yourself in #general

3. **Use the right channel** for your question type

4. **Provide context** when asking questions:
   ```
   Python version: 3.9
   Swarms version: 5.9.2
   OS: macOS 14
   Question: How do I implement custom tools with MCP?
   What I tried: [paste your code]
   Error: [paste error message]
   ```

5. **Be patient and respectful** - our community loves helping!


---

## **Feature Requests & Enhancement Suggestions**

### **When to Email for Feature Requests**

Contact us directly for:

- Major new framework capabilities

- Architecture enhancements

- New model provider integrations

- Enterprise-specific features

- Analytics and monitoring tools

- UI/UX improvements


### **How to Submit Feature Requests**

**Email**: [kye@swarms.world](mailto:kye@swarms.world)

**Subject Format**: `[FEATURE REQUEST] Brief description`

**Include in your email**:

```markdown
## Feature Description
Clear description of the proposed feature

## Use Case
Why this feature is needed and how it would be used

## Business Impact
How this would benefit the Swarms ecosystem

## Technical Requirements
Any specific technical considerations

## Priority Level
- Low: Nice to have

- Medium: Would significantly improve workflow

- High: Critical for adoption/production use


## Alternatives Considered
Other solutions you've explored

## Implementation Ideas
Any thoughts on how this could be implemented
```

### **Feature Request Process**

1. **Email submission** with detailed requirements
2. **Initial review** within 48 hours
3. **Technical feasibility** assessment
4. **Community feedback** gathering (if applicable)
5. **Roadmap planning** and timeline estimation
6. **Development** and testing
7. **Release** with documentation

---

## **Self-Service Resources**

Before reaching out for support, check these resources:

### **Documentation**

- **[Complete Documentation](https://docs.swarms.world)** - Comprehensive guides and API reference

- **[Installation Guide](https://docs.swarms.world/en/latest/swarms/install/install/)** - Setup and configuration

- **[Quick Start](https://docs.swarms.world/en/latest/quickstart/)** - Get up and running fast

- **[Examples Gallery](https://docs.swarms.world/en/latest/examples/)** - Real-world use cases


### **Common Solutions**

| Issue | Solution |
|-------|----------|
| **Installation fails** | Check [Environment Setup](https://docs.swarms.world/en/latest/swarms/install/env/) |
| **Model not responding** | Verify API keys in environment variables |
| **Import errors** | Ensure latest version: `pip install -U swarms` |
| **Memory issues** | Review [Performance Guide](https://docs.swarms.world/en/latest/swarms/framework/test/) |
| **Agent not working** | Check [Basic Agent Example](https://docs.swarms.world/en/latest/swarms/examples/basic_agent/) |

### **Video Tutorials**

- **[YouTube Channel](https://www.youtube.com/channel/UC9yXyitkbU_WSy7bd_41SqQ)** - Step-by-step tutorials

- **[Live Coding Sessions](https://www.youtube.com/channel/UC9yXyitkbU_WSy7bd_41SqQ)** - Real-world implementations


---

## **Support Checklist**

Before requesting support, please:

- [ ] **Check the documentation** for existing solutions

- [ ] **Search GitHub issues** for similar problems

- [ ] **Update to latest version**: `pip install -U swarms`

- [ ] **Verify environment setup** and API keys

- [ ] **Test with minimal code** to isolate the issue

- [ ] **Gather error messages** and relevant logs

- [ ] **Note your environment** (OS, Python version, Swarms version)


---

## **Support Best Practices**

### **For Faster Resolution**

1. **Be Specific**: Provide exact error messages and steps to reproduce
2. **Include Code**: Share minimal, runnable examples
3. **Environment Details**: Always include version information
4. **Search First**: Check if your issue has been addressed before
5. **One Issue Per Report**: Don't combine multiple problems
6. **Follow Up**: Respond promptly to requests for additional information

### **Response Time Expectations**

| Priority | Response Time | Resolution Time |
|----------|---------------|-----------------|
| **Critical** (Production down) | < 2 hours | < 24 hours |
| **High** (Major functionality blocked) | < 8 hours | < 48 hours |
| **Medium** (Feature issues) | < 24 hours | < 1 week |
| **Low** (Documentation, enhancements) | < 48 hours | Next release |

---

## **Contributing Back**

Help improve support for everyone:

- **Answer questions** in Discord or GitHub

- **Improve documentation** with your learnings

- **Share examples** of successful implementations

- **Report bugs** you discover

- **Suggest improvements** to this support process


**Your contributions make Swarms better for everyone.**

---

## **Support Channel Summary**

| Urgency | Best Channel |
|---------|-------------|
| **Emergency** | [Book Immediate Call](https://cal.com/swarms/swarms-technical-support?overlayCalendar=true) |
| **Urgent** | [Discord #technical-support](https://discord.gg/jM3Z6M9uMq) |
| **Standard** | [GitHub Issues](https://github.com/kyegomez/swarms/issues) |
| **Feature Ideas** | [Email kye@swarms.world](mailto:kye@swarms.world) |

**We're here to help you succeed with Swarms.**
